# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SystemUser.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10SystemUser.proto\x12\x15\x41\x63\x46unDanmu.Im.Message*9\n\nSystemUser\x12\x16\n\x12kSystemUserInvalid\x10\x00\x12\x13\n\x0eSYSTEM_USER_ID\x10\x90Nb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SystemUser_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SYSTEMUSER._serialized_start=43
  _SYSTEMUSER._serialized_end=100
# @@protoc_insertion_point(module_scope)
